@@ -31,11 +31,14 @@ __author__ = 'Mansour Behabadi'
 __copyright__ = 'Copyright 2011, Mansour Behabadi and Jake Gordon'
 __credits__ = ['Mansour Behabadi', 'Jake Gordon']
 __license__ = 'MIT'
-__version__ = '1.1.1'
+__version__ = '1.1.2'
 __maintainer__ = 'Mansour Behabadi'
 __email__ = 'mansour@oxplot.com'
 
 
+import collections
+
+
 WILDCARD = '*'
 
 
@@ -53,10 +56,63 @@ class Fysom(object):
         Wraps the complete finite state machine operations.
     '''
 
-    def __init__(self, cfg):
+    def __init__(self, cfg={}, initial=None, events=None, callbacks=None, final=None):
         '''
-            Machine construction.
+        Construct a Finite State Machine.
+
+        Arguments:
+
+            cfg         finite state machine specification,
+                        a dictionary with keys 'initial', 'events', 'callbacks', 'final'
+
+            initial     initial state
+
+            events      a list of dictionaries (keys: 'name', 'src', 'dst')
+                        or a list tuples (event name, source state or states,
+                        destination state or states)
+
+            callbacks   a dictionary mapping callback names to functions
+
+            final       a state of the FSM where its is_finished() method returns True
+
+        Named arguments override configuration dictionary.
+
+        Example:
+
+        >>> fsm = Fysom(events=[('tic', 'a', 'b'), ('toc', 'b', 'a')], initial='a')
+        >>> fsm.current
+        'a'
+        >>> fsm.tic()
+        >>> fsm.current
+        'b'
+        >>> fsm.toc()
+        >>> fsm.current
+        'a'
+
         '''
+        cfg = dict(cfg)
+        # override cfg with named arguments
+        if "events" not in cfg:
+            cfg["events"] = []
+        if "callbacks" not in cfg:
+            cfg["callbacks"] = {}
+        if initial:
+            cfg["initial"] = initial
+        if final:
+            cfg["final"] = final
+        if events:
+            cfg["events"].extend(list(events))
+        if callbacks:
+            cfg["callbacks"].update(dict(callbacks))
+        # convert 3-tuples in the event specification to dicts
+        events_dicts = []
+        for e in cfg["events"]:
+            if isinstance(e, collections.Mapping):
+                events_dicts.append(e)
+            elif hasattr(e, "__iter__"):
+                name, src, dst = list(e)[:3]
+                events_dicts.append({"name": name, "src": src, "dst": dst})
+        cfg["events"] = events_dicts
         self._apply(cfg)
 
     def isstate(self, state):
